[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Bug#195510: Change this mistake



Folks,

Here is a patch to solve this small issue. Please apply.

TIA,
Otavio
Index: apt-pkg/algorithms.cc
===================================================================
RCS file: /cvs/deity/apt/apt-pkg/algorithms.cc,v
retrieving revision 1.44
diff -u -r1.44 algorithms.cc
--- apt-pkg/algorithms.cc	28 Nov 2002 18:49:16 -0000	1.44
+++ apt-pkg/algorithms.cc	1 Aug 2003 13:38:26 -0000
@@ -50,26 +50,26 @@
 									/*}}}*/
 // Simulate::Describe - Describe a package				/*{{{*/
 // ---------------------------------------------------------------------
-/* Parameter Now == true gives both current and available varsion,
-   Parameter Now == false gives only the available package version */
-void pkgSimulate::Describe(PkgIterator Pkg,ostream &out,bool Now)
+/* Parameter Avail == true gives both current and available varsion,
+   Parameter Avail == false gives only the current package version */
+void pkgSimulate::Describe(PkgIterator Pkg,ostream &out,bool Avail)
 {
    VerIterator Ver(Sim);
  
    out << Pkg.Name();
 
-   if (Now == true)
-   {
-      Ver = Pkg.CurrentVer();
-      if (Ver.end() == false)
-         out << " [" << Ver.VerStr() << ']';
-   }
+   Ver = Pkg.CurrentVer();
+   if (Ver.end() == false)
+     out << " [" << Ver.VerStr() << ']';
+
+   if (Avail == true) {
+     Ver = Sim[Pkg].CandidateVerIter(Sim);
 
-   Ver = Sim[Pkg].CandidateVerIter(Sim);
-   if (Ver.end() == true)
-      return;
+     if (Ver.end() == true)
+       return;
    
-   out << " (" << Ver.VerStr() << ' ' << Ver.RelStr() << ')';
+     out << " (" << Ver.VerStr() << ' ' << Ver.RelStr() << ')';
+   }
 }
 									/*}}}*/
 // Simulate::Install - Simulate unpacking of a package			/*{{{*/
-- 
        O T A V I O    S A L V A D O R
---------------------------------------------
 E-mail: otavio@debian.org      UIN: 5906116
 GNU/Linux User: 239058     GPG ID: 49A5F855
 Home Page: http://www.freedom.ind.br/otavio
---------------------------------------------

Reply to: